==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/de.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Aufgaben",
    "{actor} created calendar {calendar}" : "{actor} hat den Kalender {calendar} erstellt",
    "You created calendar {calendar}" : "Du hast den Kalender {calendar} erstellt",
    "{actor} deleted calendar {calendar}" : "{actor} hat den Kalender {calendar} gelöscht",
    "You deleted calendar {calendar}" : "Du hast den Kalender {calendar} gelöscht",
    "{actor} updated calendar {calendar}" : "{actor} hat den Kalender {calendar} aktualisiert",
    "You updated calendar {calendar}" : "Du hast den Kalender {calendar} aktualisiert",
    "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit dir geteilt",
    "You shared calendar {calendar} with {user}" : "Du hast den Kalender {calendar} mit {user} geteilt",
    "{actor} shared calendar {calendar} with {user}" : "{actor} hat den Kalender {calendar} mit {user} geteilt",
    "{actor} unshared calendar {calendar} from you" : "{actor} teilt den Kalender {calendar} nicht mehr mit dir",
    "You unshared calendar {calendar} from {user}" : "Du teilst den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} teilt den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} teilt den Kalender {calendar} nicht mehr mit sich selbst",
    "You shared calendar {calendar} with group {group}" : "Du hast den Kalender {calendar} mit der Gruppe {group} geteilt",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} teilt den Kalender {calendar} mit der Gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Du teilst den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} teilt den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} erstellt",
    "You created event {event} in calendar {calendar}" : "Du hast das Ereignis {event} im Kalender {calendar} erstellt",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} gelöscht",
    "You deleted event {event} from calendar {calendar}" : "Du hast das Ereignis {event} im Kalender {calendar} gelöscht",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} aktualisiert",
    "You updated event {event} in calendar {calendar}" : "Du hast das Ereignis {event} im Kalender {calendar} aktualisiert",
    "{actor} created todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
    "You created todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} erstellt",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "You deleted todo {todo} from list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "You updated todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
    "You solved todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} erledigt",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wieder geöffnet",
    "You reopened todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} wieder geöffnet",
    "A <strong>calendar</strong> was modified" : "Ein <strong>Kalender</strong> wurde bearbeitet",
    "A calendar <strong>event</strong> was modified" : "Ein <strong>Ereignis</strong> wurde bearbeitet",
    "A calendar <strong>todo</strong> was modified" : "Eine <strong>Aufgabe</strong> wurde bearbeitet",
    "Contact birthdays" : "Geburtstage von Kontakten",
    "Personal" : "Persönlich",
    "Contacts" : "Kontakte",
    "Technical details" : "Technische Details",
    "Remote Address: %s" : "Remote-Adresse: %s",
    "Request ID: %s" : "Anfrage-ID: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/de.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Aufgaben",
    "{actor} created calendar {calendar}" : "{actor} hat den Kalender {calendar} erstellt",
    "You created calendar {calendar}" : "Du hast den Kalender {calendar} erstellt",
    "{actor} deleted calendar {calendar}" : "{actor} hat den Kalender {calendar} gelöscht",
    "You deleted calendar {calendar}" : "Du hast den Kalender {calendar} gelöscht",
    "{actor} updated calendar {calendar}" : "{actor} hat den Kalender {calendar} aktualisiert",
    "You updated calendar {calendar}" : "Du hast den Kalender {calendar} aktualisiert",
    "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit Dir geteilt",
    "You shared calendar {calendar} with {user}" : "Du hast den Kalender {calendar} mit {user} geteilt",
    "{actor} shared calendar {calendar} with {user}" : "{actor} hat den Kalender {calendar} mit {user} geteilt",
    "{actor} unshared calendar {calendar} from you" : "{actor} teilt den Kalender {calendar} nicht mehr mit Dir",
    "You unshared calendar {calendar} from {user}" : "Du teilst den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} teilt den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} teilt den Kalender {calendar} nicht mehr mit sich selbst",
    "You shared calendar {calendar} with group {group}" : "Du hast den Kalender {calendar} mit der Gruppe {group} geteilt",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} teilt den Kalender {calendar} mit der Gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Du teilst den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} teilt den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} erstellt",
    "You created event {event} in calendar {calendar}" : "Du hast das Ereignis {event} im Kalender {calendar} erstellt",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} gelöscht",
    "You deleted event {event} from calendar {calendar}" : "Du hast das Ereignis {event} im Kalender {calendar} gelöscht",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} hat das Ereignis {event} im Kalender {calendar} aktualisiert",
    "You updated event {event} in calendar {calendar}" : "Du hast das Ereignis {event} im Kalender {calendar} aktualisiert",
    "{actor} created todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
    "You created todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} erstellt",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "You deleted todo {todo} from list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "You updated todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
    "You solved todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} erledigt",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "You reopened todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "A <strong>calendar</strong> was modified" : "Ein <strong>Kalender</strong> wurde bearbeitet",
    "A calendar <strong>event</strong> was modified" : "Ein Kalender-<strong>Ereignis</strong> wurde bearbeitet",
    "A calendar <strong>todo</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde bearbeitet",
    "Contact birthdays" : "Geburtstage von Kontakten",
    "Personal" : "Persönlich",
    "Contacts" : "Kontakte",
    "WebDAV" : "WebDAV",
    "Technical details" : "Technische Details",
    "Remote Address: %s" : "Entfernte Adresse: %s",
    "Request ID: %s" : "Anfragekennung: %s"
},
"nplurals=2; plural=(n != 1);");
